==> deepin-voice-recorder_1.3.6.1.orig.tar.gz: deepin-voice-recorder-1.3.6.1/translations/deepin-voice-recorder_am_ET.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="am_ET" version="2.1">
<context>
    <name>FileView</name>
    <message>
        <location filename="../src/file_view.cpp" line="59"/>
        <source>Rename</source>
        <translation>እንደገና መሰየሚያ</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="61"/>
        <source>Display in file manager</source>
        <translation>በ ፋይል አስተዳዳሪ ውስጥ ማሳያ</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="63"/>
        <source>Move to trash</source>
        <translation>ወደ ቆሻሻ ማንቀሳቀሻ</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="53"/>
        <source>New recording</source>
        <translation>አዲስ መቅረጫ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="55"/>
        <source>Open saved directory</source>
        <translation>የ ተቀመጠ ዳይሬክቶሪ መክፈቻ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="57"/>
        <source>About</source>
        <translation>ስለ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="59"/>
        <source>Help</source>
        <translation>እርዳታ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="61"/>
        <source>Exit</source>
        <translation>መውጫ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="168"/>
        <source>Deepin Voice Recorder is a beautiful and easy to use voice recording application with simple design. It supports visual recording, recording playback, recording list management and other functions.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="180"/>
        <source>Deepin Voice Recorder</source>
        <translation>የ ዲፕኢን ድምፅ መቅረጫ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="181"/>
        <source>Version</source>
        <translation>እትም</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Voice Recorder</source>
        <translation>የ ዲፕኢን ድምፅ መቅረጫ</translation>
    </message>
</context>
<context>
    <name>RecordPage</name>
    <message>
        <location filename="../src/record_page.cpp" line="55"/>
        <location filename="../src/record_page.cpp" line="219"/>
        <source>New recording</source>
        <translation>አዲስ መቅረጫ</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/utils.cpp" line="136"/>
        <source>Recording</source>
        <translation>መቅረጫ</translation>
    </message>
</context>
</TS>

==> deepin-voice-recorder_1.3.7.orig.tar.gz: deepin-voice-recorder-1.3.7/translations/deepin-voice-recorder_am_ET.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="am_ET" version="2.1">
<context>
    <name>FileView</name>
    <message>
        <location filename="../src/file_view.cpp" line="59"/>
        <source>Rename</source>
        <translation>እንደገና መሰየሚያ</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="61"/>
        <source>Display in file manager</source>
        <translation>በ ፋይል አስተዳዳሪ ውስጥ ማሳያ</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="63"/>
        <source>Move to trash</source>
        <translation>ወደ ቆሻሻ ማንቀሳቀሻ</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="53"/>
        <source>New recording</source>
        <translation>አዲስ መቅረጫ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="55"/>
        <source>Open saved directory</source>
        <translation>የ ተቀመጠ ዳይሬክቶሪ መክፈቻ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="57"/>
        <source>About</source>
        <translation>ስለ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="59"/>
        <source>Help</source>
        <translation>እርዳታ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="61"/>
        <source>Exit</source>
        <translation>መውጫ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="168"/>
        <source>Deepin Voice Recorder is a beautiful and easy to use voice recording application with simple design. It supports visual recording, recording playback, recording list management and other functions.</source>
        <translation>ዲፕኢን የ ድምፅ መቅረጫ ዘመናዊ እና ለ መጠቀም በጣም ቀላል መተግበሪያ ነው: የሚደግፈውም የሚታይ መቅረጫ: የ ቀረጸውን መልሶ ማጫወቻ: እና የ ቀረጸውን ዝርዝር ያሳያል እንዲሁም ሌሎች ተግባሮች</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="180"/>
        <source>Deepin Voice Recorder</source>
        <translation>የ ዲፕኢን ድምፅ መቅረጫ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="181"/>
        <source>Version</source>
        <translation>እትም</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Voice Recorder</source>
        <translation>የ ዲፕኢን ድምፅ መቅረጫ</translation>
    </message>
</context>
<context>
    <name>RecordPage</name>
    <message>
        <location filename="../src/record_page.cpp" line="55"/>
        <location filename="../src/record_page.cpp" line="219"/>
        <source>New recording</source>
        <translation>አዲስ መቅረጫ</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/utils.cpp" line="136"/>
        <source>Recording</source>
        <translation>መቅረጫ</translation>
    </message>
</context>
</TS>
